@@ -216,16 +216,21 @@ R_TextureMode(char *string)
 		ri.Cvar_SetValue("gl_anisotropic", 0.0);
 	}
 
+	const char* nolerplist = gl_nolerp_list->string;
+
 	/* change all the existing mipmap texture objects */
 	for (i = 0, glt = gltextures; i < numgltextures; i++, glt++)
 	{
-		if ((glt->type != it_pic) && (glt->type != it_sky))
+		if (nolerplist != NULL && strstr(nolerplist, glt->name) != NULL)
 		{
-			R_Bind(glt->texnum);
-			glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER,
-					gl_filter_min);
-			glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER,
-					gl_filter_max);
+			continue; /* those (by default: font and crosshairs) always only use GL_NEAREST */
+		}
+
+		R_Bind(glt->texnum);
+		if ((glt->type != it_pic) && (glt->type != it_sky)) /* mipmapped texture */
+		{
+			glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, gl_filter_min);
+			glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, gl_filter_max);
 
 			/* Set anisotropic filter if supported and enabled */
 			if (gl_config.anisotropic && gl_anisotropic->value)
@@ -234,6 +239,13 @@ R_TextureMode(char *string)
 						gl_anisotropic->value);
 			}
 		}
+		else /* texture has no mipmaps */
+		{
+			// we can't use gl_filter_min which might be GL_*_MIPMAP_*
+			// also, there's no anisotropic filtering for textures w/o mipmaps
+			glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, gl_filter_max);
+			glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, gl_filter_max);
+		}
 	}
 }
 
@@ -342,21 +354,17 @@ R_FloodFillSkin(byte *skin, int skinwidth, int skinheight)
 	byte fillcolor = *skin; /* assume this is the pixel to fill */
 	floodfill_t fifo[FLOODFILL_FIFO_SIZE];
 	int inpt = 0, outpt = 0;
-	int filledcolor = -1;
+	int filledcolor = 0;
 	int i;
 
-	if (filledcolor == -1)
+	// NOTE: there was a if(filledcolor == -1) which didn't make sense b/c filledcolor used to be initialized to -1
+	/* attempt to find opaque black */
+	for (i = 0; i < 256; ++i)
 	{
-		filledcolor = 0;
-
-		/* attempt to find opaque black */
-		for (i = 0; i < 256; ++i)
+		if (LittleLong(d_8to24table[i]) == (255 << 0)) /* alpha 1.0 */
 		{
-			if (LittleLong(d_8to24table[i]) == (255 << 0)) /* alpha 1.0 */
-			{
-				filledcolor = i;
-				break;
-			}
+			filledcolor = i;
+			break;
 		}
 	}
 
@@ -646,6 +654,7 @@ R_Upload32Soft(unsigned *data, int width, int height, qboolean mipmap)
 
 	if (scaled_width * scaled_height > sizeof(scaled) / 4)
 	{
+		// this can't really happen (because they're clamped to 256 above), but whatever
 		ri.Sys_Error(ERR_DROP, "R_Upload32: too big");
 	}
 
