@@ -32,7 +32,7 @@
 #include "shared.h"
 #include "crc.h"
 
-#define YQ2VERSION "7.42"
+#define YQ2VERSION "7.43"
 #define BASEDIRNAME "baseq2"
 
 #ifndef YQ2OSTYPE
@@ -53,22 +53,6 @@
  #define CFGDIR ".yq2"
 #endif
 
-// stuff to align variables/arrays
-#if __STDC_VERSION__ >= 201112L // C11 or newer
-	#define YQ2_ALIGNAS_SIZE(SIZE)  _Alignas(SIZE)
-	#define YQ2_ALIGNAS_TYPE(TYPE)  _Alignas(TYPE)
-#elif defined(__GNUC__) // GCC and clang should support this attribute
-	#define YQ2_ALIGNAS_SIZE(SIZE)  __attribute__(( __aligned__(SIZE) ))
-	#define YQ2_ALIGNAS_TYPE(TYPE)  __attribute__(( __aligned__(__alignof__(TYPE)) ))
-#elif defined(_MSC_VER)
-	#define YQ2_ALIGNAS_SIZE(SIZE)  __declspec( align(SIZE) )
-	#define YQ2_ALIGNAS_TYPE(TYPE)  __declspec( align( __alignof(TYPE) ) )
-#else
-	#warning "Please add a case for your compiler here to align correctly"
-	#define YQ2_ALIGNAS_TYPE(TYPE)
-#endif
-
-
 /* ================================================================== */
 
 typedef struct sizebuf_s
@@ -726,8 +710,8 @@ void Com_Printf(char *fmt, ...) __attribute__ ((format (printf, 1, 2)));
 void Com_DPrintf(char *fmt, ...) __attribute__ ((format (printf, 1, 2)));
 void Com_VPrintf(int print_level, const char *fmt, va_list argptr); /* print_level is PRINT_ALL or PRINT_DEVELOPER */
 void Com_MDPrintf(char *fmt, ...) __attribute__ ((format (printf, 1, 2)));
-void Com_Error(int code, char *fmt, ...) __attribute__ ((format (printf, 2, 3)));
-void Com_Quit(void);
+YQ2_ATTR_NORETURN void Com_Error(int code, char *fmt, ...) __attribute__ ((format (printf, 2, 3)));
+YQ2_ATTR_NORETURN void Com_Quit(void);
 
 /* Ugly hack: Apprently (our?) MinGW-gcc under Windows
    doesn't support %zd and requires %Id. */
@@ -813,8 +797,8 @@ void SV_Frame(int msec);
 // system.c
 char *Sys_ConsoleInput(void);
 void Sys_ConsoleOutput(char *string);
-void Sys_Error(char *error, ...);
-void Sys_Quit(void);
+YQ2_ATTR_NORETURN void Sys_Error(char *error, ...);
+YQ2_ATTR_NORETURN void Sys_Quit(void);
 void Sys_Init(void);
 char *Sys_GetHomeDir(void);
 void Sys_Remove(const char *path);
