@@ -196,8 +196,8 @@ Pickup_Powerup(edict_t *ent, edict_t *other)
 
 	quantity = other->client->pers.inventory[ITEM_INDEX(ent->item)];
 
-	if (((skill->value == 1) &&
-		 (quantity >= 2)) || ((skill->value >= 2) && (quantity >= 1)))
+	if (((skill->value == SKILL_MEDIUM) &&
+		 (quantity >= 2)) || ((skill->value >= SKILL_HARD) && (quantity >= 1)))
 	{
 		return false;
 	}
@@ -1301,13 +1301,13 @@ Drop_Item(edict_t *ent, gitem_t *item)
 	dropped->s.effects = item->world_model_flags;
 	dropped->s.renderfx = RF_GLOW;
 
-	if (randk() > 0.5)
+	if (frandk() > 0.5)
 	{
-		dropped->s.angles[1] += randk()*45;
+		dropped->s.angles[1] += frandk()*45;
 	}
 	else
 	{
-		dropped->s.angles[1] -= randk()*45;
+		dropped->s.angles[1] -= frandk()*45;
 	}
 
 	VectorSet (dropped->mins, -16, -16, -16);
